function Y = delay_reconstruct(y, tau, m)
%
% arguments:
%  x: observation series
%  tau: lag
%  m: dimensions
%
% return:
%  Y: an array containing a series of m-dimensional points
%

% compute the number of points
%
len = length(y) - (m-1)*tau;

% initialize Y
%
Y = zeros(len, m);

% reconstruct Y from y using delay reconstruction method
%
for i = 1:len
    for j = 1:m        
        Y(i,j) = y(i+((j-1)*tau));
    end
end